@@ -833,7 +833,7 @@ void Applet::flushPendingConstraintsEvents()
     if ((c & Plasma::SizeConstraint || c & Plasma::FormFactorConstraint) &&
         aspectRatioMode() == Plasma::ConstrainedSquare) {
         if (formFactor() == Horizontal) {
-            setSizePolicy(QSizePolicy(QSizePolicy::Maximum,QSizePolicy::Expanding));
+            setSizePolicy(QSizePolicy(QSizePolicy::Fixed,QSizePolicy::Expanding));
         } else if (formFactor() == Vertical) {
             setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Fixed));
         }
@@ -1695,7 +1695,9 @@ QString AppletPrivate::instanceName()
 
 void AppletPrivate::scheduleConstraintsUpdate(Plasma::Constraints c)
 {
-    if (!constraintsTimerId) {
+    // Don't start up a timer if we're just starting up
+    // flushPendingConstraints will be called by Corona
+    if (!constraintsTimerId && !(c & Plasma::StartupCompletedConstraint)) {
         constraintsTimerId = q->startTimer(0);
     }
     pendingConstraints |= c;
