@@ -764,10 +764,7 @@ void Containment::dropEvent(QGraphicsSceneDragDropEvent *event)
             //             kDebug() << mimeName;
             KPluginInfo::List appletList = Applet::listAppletInfoForMimetype(mimeName);
 
-            if (appletList.isEmpty()) {
-                // no special applet associated with this mimetype, let's
-                addApplet("icon", args, geom);
-            } else {
+            if (!appletList.isEmpty()) {
                 //TODO: should we show a dialog here to choose which plasmoid load if
                 //!appletList.isEmpty()
                 QMenu choices;
@@ -788,6 +785,10 @@ void Containment::dropEvent(QGraphicsSceneDragDropEvent *event)
                 if (choice) {
                     addApplet(actionsToPlugins[choice], args, geom);
                 }
+            } else if (url.protocol() != "data") {
+                // We don't try to do anything with data: URIs
+                // no special applet associated with this mimetype, let's
+                addApplet("icon", args, geom);
             }
         }
         event->acceptProposedAction();
@@ -841,9 +842,7 @@ bool Containment::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
         //kDebug() << "got hoverenterEvent" << immutability() << " " << applet->immutability();
         if (immutability() == Mutable && applet->immutability() == Mutable) {
             QGraphicsSceneHoverEvent *he = static_cast<QGraphicsSceneHoverEvent*>(event);
-            if (d->handles.contains(applet)) {
-                d->handles[applet]->startFading(AppletHandle::FadeIn, he->pos());
-            } else {
+            if (!d->handles.contains(applet)) {
                 //kDebug() << "generated applet handle";
                 AppletHandle *handle = new AppletHandle(this, applet, he->pos());
                 d->handles[applet] = handle;
@@ -854,14 +853,6 @@ bool Containment::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
             }
         }
         break;
-    case QEvent::GraphicsSceneHoverLeave:
-        //kDebug() << "got hoverLeaveEvent";
-        if (d->handles.contains(applet)) {
-            QGraphicsSceneHoverEvent *he = static_cast<QGraphicsSceneHoverEvent *>(event);
-            if (!d->handles[applet]->boundingRect().contains(d->handles[applet]->mapFromScene(he->scenePos()))) {
-                d->handles[applet]->startFading(AppletHandle::FadeOut, he->pos());
-            }
-        }
     default:
         break;
     }
@@ -1153,6 +1144,7 @@ void ContainmentPrivate::handleDisappeared(AppletHandle *handle)
 {
     if (handles.contains(handle->applet())) {
         handles.remove(handle->applet());
+        handle->detachApplet();
         handle->deleteLater();
     }
 }
@@ -1285,6 +1277,13 @@ void ContainmentPrivate::appletDestroyed(QObject* object)
     if (focusedApplet == applet) {
         focusedApplet = 0;
     }
+
+    if (handles.contains(applet)) {
+        AppletHandle *handle = handles.value(applet);
+        handles.remove(handle->applet());
+        handle->deleteLater();
+    }
+
     emit q->appletRemoved(applet);
     emit q->configNeedsSaving();
 }
